@@ -24,9 +24,9 @@ def zfc(create, log):
 
     os.mkdir(object_name)
     src_dir = object_name + '/src'
-    config_file = object_name + "config.json"
+    config_file = object_name + "/config.json"
     os.mkdir(src_dir)
-    with open(config_file, "wb") as fp:
+    with open(config_file, "w") as fp:
         json.dump(DEFAULT_CONF, fp)
 
 
